summaryrefslogtreecommitdiffstats
path: root/video
diff options
context:
space:
mode:
authorwm4 <wm4@nowhere>2014-11-09 10:00:21 +0100
committerwm4 <wm4@nowhere>2014-11-09 10:01:16 +0100
commit3d7d1f3f264e55857c83b8a94aa24081ae45dd4d (patch)
treefc576981333d8b0fe3702f0e38a0fc67c5d68562 /video
parentb021d038c2217903e511ca3673d5f2f1b996c4d4 (diff)
downloadmpv-3d7d1f3f264e55857c83b8a94aa24081ae45dd4d.tar.bz2
mpv-3d7d1f3f264e55857c83b8a94aa24081ae45dd4d.tar.xz
video/out: minor simplification to event query function
The "clear" parameter is confusing and useless.
Diffstat (limited to 'video')
-rw-r--r--video/out/vo.c9
-rw-r--r--video/out/vo.h2
2 files changed, 5 insertions, 6 deletions
diff --git a/video/out/vo.h b/video/out/vo.h
index 60e887444c..a083437397 100644
--- a/video/out/vo.h
+++ b/video/out/vo.h
@@ -316,7 +316,7 @@ void vo_set_paused(struct vo *vo, bool paused);
int64_t vo_get_drop_count(struct vo *vo);
int vo_query_format(struct vo *vo, int format);
void vo_event(struct vo *vo, int event);
-int vo_query_events(struct vo *vo, int events, bool clear);
+int vo_query_and_reset_events(struct vo *vo, int events);
void vo_set_flip_queue_offset(struct vo *vo, int64_t us);
int64_t vo_get_vsync_interval(struct vo *vo);
diff --git a/video/out/vo.c b/video/out/vo.c
index f697002f92..7e2bcfb83e 100644
--- a/video/out/vo.c
+++ b/video/out/vo.c
@@ -840,7 +840,7 @@ int64_t vo_get_vsync_interval(struct vo *vo)
}
// Set specific event flags, and wakeup the playback core if needed.
// vo_query_events() can retrieve the events again.
void vo_event(struct vo *vo, int event)
{
struct vo_internal *in = vo->in;
@@ -852,14 +852,13 @@ void vo_event(struct vo *vo, int event)
}
// Check event flags set with vo_event(). Return the mask of events that was
-// set and included in the events parameter. If clear==true, clear these events.
-int vo_query_events(struct vo *vo, int events, bool clear)
+// set and included in the events parameter. Clear the returned events.
+int vo_query_and_reset_events(struct vo *vo, int events)
{
struct vo_internal *in = vo->in;
pthread_mutex_lock(&in->lock);
int r = in->queued_events & events;
- if (clear)
- in->queued_events &= ~(unsigned)r;
+ in->queued_events &= ~(unsigned)r;
pthread_mutex_unlock(&in->lock);
return r;
}
@@ -840,7 +840,7 @@ int64_t vo_get_vsync_interval(struct vo *vo)
}
// Set specific event flags, and wakeup the playback core if needed.
-// vo_query_events() can retrieve the events again.
+// vo_query_and_reset_events() can retrieve the events again.
void vo_event(struct vo *vo, int event)
{